@@ -16,9 +16,9 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -309,6 +309,12 @@ cogl_program_uniform_1f (int uniform_no,
 {
 }
 
+void
+cogl_program_uniform_1i (int uniform_no,
+                         int    value)
+{
+}
+
 void
 cogl_program_uniform_float (int  uniform_no,
                             int     size,
